@@ -21,16 +21,16 @@ __PACKAGE__->add_columns(
   "time_first",
   {
     data_type     => "timestamp",
-    default_value => \"current_timestamp",
+    default_value => \"LOCALTIMESTAMP",
     is_nullable   => 1,
-    original      => { default_value => \"now()" },
+    original      => { default_value => \"LOCALTIMESTAMP" },
   },
   "time_last",
   {
     data_type     => "timestamp",
-    default_value => \"current_timestamp",
+    default_value => \"LOCALTIMESTAMP",
     is_nullable   => 1,
-    original      => { default_value => \"now()" },
+    original      => { default_value => \"LOCALTIMESTAMP" },
   },
 );
 __PACKAGE__->set_primary_key("mac", "ip");
